==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebGridToolbarHidingDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseToolbarColumnActionsDirectiveDescriptionMetadata } from "./WebBaseToolbarColumnActionsDirectiveDescriptionMetadata";
import { WebGridToolbarHidingDescription } from "./WebGridToolbarHidingDescription";
/**
 * @hidden
 */
var WebGridToolbarHidingDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridToolbarHidingDescriptionMetadata, _super);
    function WebGridToolbarHidingDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridToolbarHidingDescriptionMetadata.b = function (a) {
        if (WebGridToolbarHidingDescriptionMetadata.a == null) {
            WebGridToolbarHidingDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridToolbarHidingDescriptionMetadata.c(WebGridToolbarHidingDescriptionMetadata.a);
        }
        if (a.k(WebGridToolbarHidingDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebGridToolbarHidingDescriptionMetadata.a);
    };
    WebGridToolbarHidingDescriptionMetadata.c = function (a) {
        WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:GridToolbarHiding");
        a.item("__tagNameWC", "String:igc-grid-toolbar-hiding");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        if (a.containsKey("__skipSuffix")) {
            a.removeItem("__skipSuffix");
        }
        a.item("__manageItemInMarkup", "Boolean");
    };
    WebGridToolbarHidingDescriptionMetadata.d = function (a) {
        WebGridToolbarHidingDescriptionMetadata.b(a);
        a.ad("WebGridToolbarHiding", function () { return new WebGridToolbarHidingDescription(); });
        a.ac("WebGridToolbarHiding", WebGridToolbarHidingDescriptionMetadata.a);
    };
    WebGridToolbarHidingDescriptionMetadata.$t = markType(WebGridToolbarHidingDescriptionMetadata, 'WebGridToolbarHidingDescriptionMetadata');
    WebGridToolbarHidingDescriptionMetadata.a = null;
    return WebGridToolbarHidingDescriptionMetadata;
}(Base));
export { WebGridToolbarHidingDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebGridToolbarHidingDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseToolbarColumnActionsDirectiveDescriptionMetadata } from "./WebBaseToolbarColumnActionsDirectiveDescriptionMetadata";
import { WebGridToolbarHidingDescription } from "./WebGridToolbarHidingDescription";
/**
 * @hidden
 */
var WebGridToolbarHidingDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridToolbarHidingDescriptionMetadata, _super);
    function WebGridToolbarHidingDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridToolbarHidingDescriptionMetadata.b = function (a) {
        if (WebGridToolbarHidingDescriptionMetadata.a == null) {
            WebGridToolbarHidingDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridToolbarHidingDescriptionMetadata.c(WebGridToolbarHidingDescriptionMetadata.a);
        }
        if (a.k(WebGridToolbarHidingDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebGridToolbarHidingDescriptionMetadata.a);
    };
    WebGridToolbarHidingDescriptionMetadata.c = function (a) {
        WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:GridToolbarHiding");
        a.item("__tagNameWC", "String:igc-grid-toolbar-hiding");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        if (a.containsKey("__skipSuffix")) {
            a.removeItem("__skipSuffix");
        }
        a.item("__manageItemInMarkup", "Boolean");
    };
    WebGridToolbarHidingDescriptionMetadata.d = function (a) {
        WebGridToolbarHidingDescriptionMetadata.b(a);
        a.ae("WebGridToolbarHiding", function () { return new WebGridToolbarHidingDescription(); });
        a.ad("WebGridToolbarHiding", WebGridToolbarHidingDescriptionMetadata.a);
    };
    WebGridToolbarHidingDescriptionMetadata.$t = markType(WebGridToolbarHidingDescriptionMetadata, 'WebGridToolbarHidingDescriptionMetadata');
    WebGridToolbarHidingDescriptionMetadata.a = null;
    return WebGridToolbarHidingDescriptionMetadata;
}(Base));
export { WebGridToolbarHidingDescriptionMetadata };
